| Title: | Data from the GLM Book by Dobson and Barnett |
|---|---|
| Description: | Example datasets from the book "An Introduction to Generalised Linear Models" (Year: 2018, ISBN:9781138741515) by Dobson and Barnett. |
| Authors: | Adrian Barnett [aut, cre] |
| Maintainer: | Adrian Barnett <[email protected]> |
| License: | GPL-2 |
| Version: | 0.4 |
| Built: | 2026-05-13 09:57:05 UTC |
| Source: | https://github.com/agbarnett/dobson |
Achievement scores after three training methods
data(achieve)data(achieve)
A tibble with 21 observations and the following 3 variables.
methodtraining method (A, B or C)
yachievement scores
xaptitude scores measured before training commenced
Winer, B. J. (1971). Statistical Principles in Experimental Design (2nd ed.).
data(achieve) summary(achieve)data(achieve) summary(achieve)
Achievement scores after three training methods
data(achievement)data(achievement)
A tibble with 21 observations and the following 3 variables.
methodtraining method (A, B or C)
yachievement scores
xaptitude scores measured before training commenced
Winer, B. J. (1971). Statistical Principles in Experimental Design (2nd ed.).
data(achievement) summary(achievement)data(achievement) summary(achievement)
Numbers of cases of AIDS in Australia by date of diagnosis for successive 3-month periods from 1984 to 1988
data(aids)data(aids)
A tibble with 20 observations and the following 3 variables.
yearyear
quarterquarter of year
casesnumber of cases
National Centre for HIV Epidemiology and Clinical Research 1994
data(aids) summary(aids)data(aids) summary(aids)
Numbers of embryogenic anthers of the plant species Datura innoxia Mill obtained when anthers were prepared under several different conditions
data(anthers)data(anthers)
A tibble with 6 observations and the following 4 variables.
ynumbers of embryogenic anthers
nnumber of anthers
newstorstorage condition, 0=control or 1=treatment
xlog (base e) of centrifuging force (g)
Sangwan-Norrell, B. S. (1977). Androgenic stimulating factor in the anther and isolated pollen grain culture of Datura innoxia mill. Journal of Experimental Biology 28, 843–852.
data(anthers) summary(anthers)data(anthers) summary(anthers)
Fictitious balanced data for a two-factor ANOVA with equal numbers of observations in each subgroup
data(balanced)data(balanced)
A tibble with 12 observations and the following 3 variables.
factorAfactor A
factorBfactor B
datadependent data
data(balanced) summary(balanced)data(balanced) summary(balanced)
Numbers of beetles dead after five hours exposure to gaseous carbon disulphide at various concentrations
data(beetle)data(beetle)
A tibble with 6 observations and the following 3 variables.
xdose (log base 10 CS2mgl^-1)
nnumber of beetles
ynumbers killed
Bliss, C. I. (1935). The calculation of the dose-mortality curve. Annals of Applied Biology 22, 134–167.
data(beetle) summary(beetle)data(beetle) summary(beetle)
Birthweight and gestational age for twelve boys and girls
data(birthweight)data(birthweight)
A tibble with 12 observations and the following 4 variables.
boys gestational ageboys gestational age (weeks)
boys weightboys birthweight (grams)
girls gestational agegirls gestational age (weeks)
girls weightgirls birthweight (grams)
data(birthweight) summary(birthweight)data(birthweight) summary(birthweight)
Percentages of total calories obtained from complex carbohydrates, for twenty male insulin-dependent diabetics who had been on a high-carbohydrate diet for six months.
data(carbohydrate)data(carbohydrate)
A tibble with 20 observations and the following 4 variables.
carbohydratepercent of total calories obtained from complex carbohydrates
ageage in years
weightbody weight relative to "ideal" weight for height
proteinpercentage of calories as protein
K. Webb
data(carbohydrate) summary(carbohydrate)data(carbohydrate) summary(carbohydrate)
Preferences for air conditioning and power steering in cars by gender and age.
data(Cars)data(Cars)
A tibble with 18 observations and the following 4 variables.
sexsex
ageage group
responseordinal response
frequencyfrequency
McFadden, M., J. Powers, W. Brown, and M. Walker (2000). Vehicle and driver attributes affecting distance from the steering wheel in motor vehicles. Human Factors 42, 676–682.
data(Cars) summary(Cars)data(Cars) summary(Cars)
Cholesterol, age and BMI for thirty women.
data(cholesterol)data(cholesterol)
A tibble with 30 observations and the following 3 variables.
cholserum cholesterol (millimoles per liter)
ageage (years)
bmibody mass index (kg/m2)
data(cholesterol) summary(cholesterol)data(cholesterol) summary(cholesterol)
Numbers of chronic medical conditions reported by samples of women living in large country towns (town group) or in more rural areas (country group) in New South Wales, Australia
data(chronic)data(chronic)
A data frame with 49 observations and the following 2 variables.
placeplace (town or country)
numbernumber of conditions
data(chronic) summary(chronic)data(chronic) summary(chronic)
The number of tropical cyclones during a season from November to April in Northeastern Australia
data(cyclones)data(cyclones)
A tibble with 13 observations and the following 3 variables.
yearsseason years
seasonseason number
numbernumber of cyclones
Dobson AJ and Stewart J (1974). Frequencies of tropical cyclones in the northeastern Australian area. Australian Meteorological Magazine 22, 27–36.
data(cyclones) summary(cyclones)data(cyclones) summary(cyclones)
Data from the famous doctors study of smoking conducted by Sir Richard Doll and colleagues
data(doctors)data(doctors)
A tibble with 10 observations and the following 5 variables.
ageage group; 1=35 to 44 years, 2=45 to 54 years, 3=55 to 64 years, 4=65 to 74 years, 5=75 to 84 years
agesqage group squared
smokingsmoker or non-smoker
deathsnumber of deaths
personyearsperson years of of observation at the time of the analysis
Breslow, N. E. and N. E. Day (1987). Statistical Methods in Cancer Research, Volume 2: The Design and Analysis of Cohort Studies. Lyon: International Agency for Research on Cancer.
data(doctors) summary(doctors)data(doctors) summary(doctors)
Measurements of left ventricular volume and parallel conductance volume on five dogs under eight different load conditions
data(dogs)data(dogs)
A tibble with 40 observations and the following 4 variables.
dogdog number
conditionload condition
yleft ventricular volume
xparallel conductance volume
Boltwood, C. M., R. Appleyard, and S. A. Glantz (1989). Left ventricular volume measurement by conductance catheter in intact dogs: the parallel conductance volume increases with end-systolic volume. Circulation 80, 1360–1377.
data(dogs) summary(dogs)data(dogs) summary(dogs)
Numbers of ears clear of acute otitis media at 14 days by antibiotic treatment and age of the child. The children had acute otitis media in both ears.
data(ear)data(ear)
A tibble with 18 observations and the following 4 variables.
agechild's age
treatmenttwo treatments coded CEF and AMO
number clearnumber of clear ears
frequencyfaculty
Rosner, B. (1989). Multivariate methods for clustered binary data with more than one level of nesting. Journal of the American Statistical Association 84, 373–380.
data(ear) summary(ear)data(ear) summary(ear)
Lifetimes of Kevlar epoxy strand pressure vessels at 70
data(failure)data(failure)
A tibble with 49 observations and the following variable.
lifetimestime to failure in hours
Andrews, D. F. and A. M. Herzberg (1985). Data: A Collection of Problems from Many Fields for the Student and Research Worker. New York: Springer Verlag.
data(failure) summary(failure)data(failure) summary(failure)
Survival 50 years after graduation of men and women who graduated each year from 1938 to 1947 from various Faculties of the University of Adelaide.
data(graduates)data(graduates)
A tibble with 60 observations and the following 5 variables.
yearyear of graduation
survivenumber of graduates who survived
totaltotal number of graduates
facultyfaculty
sexsex
J.A. Keats
data(graduates) summary(graduates)data(graduates) summary(graduates)
Survival times in months of patients with chronic active hepatitis in a randomized controlled trial of prednisolone versus no treatment
data(hepatitis)data(hepatitis)
A tibble with 44 observations and the following 3 variables.
survival timesurvival time in months
censorcensored, lost to follow up or died
groupprednisolone or no treatment
Altman DG, Bland JM (1998). Statistical notes: times to event (survival) data. British Medical Journal 317, 468–469.
data(hepatitis) summary(hepatitis)data(hepatitis) summary(hepatitis)
The number of deaths from leukemia and other cancers among survivors of the Hiroshima atom bomb. The data are for deaths during the period 1950– 1959 among survivors who were aged 25 to 64 years in 1950.
data(hiroshima)data(hiroshima)
A tibble with 6 observations and the following 4 variables.
radiationradiation dose (rads)
leukemialeukemia deaths
other cancerdeaths from other cancers
total cancerstotal cancer deaths
Cox, D. R. and E. J. Snell (1981). Applied Statistics: Principles and Examples. London: Chapman & Hall.
Otake, M. (1979). Comparison of time risks based on a multinomial logistic response model in longitudinal studies. Technical Report No. 5, RERF, Hiroshima, Japan.
data(hiroshima) summary(hiroshima)data(hiroshima) summary(hiroshima)
Data from an investigation into satisfaction with housing conditions in Copenhagen
data(housing)data(housing)
A tibble with 18 observations and the following 4 variables.
typehousing type; tower block, apartment or house
satisfactionsatisfaction; low, medium or high
contactcontact with other residents; low or high
frequencyfrequency
Madsen, M. (1971). Statistical analysis of multiple contingency tables. two examples. Scandinavian Journal of Statistics 3, 97–106.
data(housing) summary(housing)data(housing) summary(housing)
Insurance claim data by car category, age group and district.
data(insurance)data(insurance)
A tibble with 32 observations and the following 5 variables.
carcar insurance category
ageage group
districtdistrict where policy holder lived; 1=major city, 0=elsewhere
ynumber of claims
nnumber of insurance policies
Baxter, L. A., S. M. Coutts, and G. A. F. Ross (1980). Applications of linear models in motor insurance. Zurich, pp. 11–29. Proceedings of the 21st International Congress of Actuaries.
data(insurance) summary(insurance)data(insurance) summary(insurance)
Survival times and white blood cell count for seventeen patients suffering from leukemia
data(leukemia)data(leukemia)
A tibble with 17 observations and the following 2 variables.
timetime to death in weeks
wbclog base 10 initial white blood cell count
Cox, D. R. and E. J. Snell (1981). Applied Statistics: Principles and Examples. London: Chapman & Hall.
data(leukemia) summary(leukemia)data(leukemia) summary(leukemia)
Weights of machine components made by workers on different days
data(machine)data(machine)
A tibble with 44 observations and the following 3 variables.
dayday number 1 or 2
workerworker nunber 1 to 4
weightweight in grams
data(machine) summary(machine)data(machine) summary(machine)
A cross-sectional study of patients with a form of skin cancer called malignant melanoma
data(melanoma)data(melanoma)
A tibble with 12 observations and the following 3 variables.
tumortumor type
sitesite of cancer
frequencyfrequency
Roberts, G., A. L. Martyn, A. J. Dobson, and W. H. McCarthy (1981). Tumour thickness and histological type in malignant melanoma in New South Wales, Australia, 1970–76. Pathology 13, 763–770.
data(melanoma) summary(melanoma)data(melanoma) summary(melanoma)
Numbers of deaths from coronary heart disease and population sizes by 5-year age groups for men in the Hunter region of New South Wales, Australia in 1991.
data(mortality)data(mortality)
A tibble with 8 observations and the following 3 variables.
age groupage group (years)
deathsnumber of deaths
populationpopulation size
data(mortality) summary(mortality)data(mortality) summary(mortality)
Numbers of females and males in the progeny of 16 female light brown apple moths in Muswellbrook, New South Wales, Australia
data(moths)data(moths)
A tibble with 16 observations and the following 3 variables.
groupprogeny group
femalesnumber of females
malesnumber of males
Lewis T (1987). Uneven sex ratios in the light brown apple moth: a problem in outlier allocation. In D. J. Hand and B. S. Everitt (Eds.), The Statistical Consultant in Action. Cambridge: Cambridge University Press.
data(moths) summary(moths)data(moths) summary(moths)
Response of a grass and legume pasture system to various quantities of phosphorus fertilizer
data(pasture)data(pasture)
A tibble with 27 observations and the following 2 variables.
Kphosphorus levels (kilograms per hectare)
yieldtotal yield of grass and legume together (kilograms per hectare)
D. F. Sinclair
data(pasture) summary(pasture)data(pasture) summary(pasture)
Dried weights of plants from three different growing conditions
data(plant.dried)data(plant.dried)
A tibble with 20 observations and the following 4 variables.
carbohydratepercent of total calories obtained from complex carbohydrates
ageage in years
weightbody weight relative to "ideal" weight for height
proteinpercentage of calories as protein
K. Webb
data(plant.dried) summary(plant.dried)data(plant.dried) summary(plant.dried)
Dried weight of plants grown under two conditions.
data(plants)data(plants)
A tibble with 20 observations and the following 2 variables.
treatmentweights of treatment plants in grams
controlweights of control plants in grams
data(plants) summary(plants)data(plants) summary(plants)
Dried weights of plants from three different growing conditions
data(plantwt)data(plantwt)
A tibble with 30 observations and the following 2 variables.
weightdried weight
groupgrowing condition: control, treatmentA or treatmentB
data(plantwt) summary(plantwt)data(plantwt) summary(plantwt)
Plasma phosphate levels in obese and control participants one hour after a standard glucose tolerance test.
data(plasma)data(plasma)
A tibble with 31 observations and the following 2 variables.
Groupgroup; H-O=Hyperinsulinemic obsese, N-O=Non-hyperinsulinemic obese or C=Control
phosphateplasma inorganic phosphate level (mg/dl)
data(plasma) summary(plasma)data(plasma) summary(plasma)
Data from 878 journal articles published in PLOS Medicine between 2011 and 2015
data(PLOS)data(PLOS)
A data.frame with 878 observations and the following 2 variables.
nchartitle length
authorsnumber of authors, truncated to 30
data(PLOS) summary(PLOS)data(PLOS) summary(PLOS)
Artificial data for a Poisson regression example
data(poisson)data(poisson)
A tibble with 9 observations and the following two variables.
xcovariate
ydependent counts
data(poisson) summary(poisson)data(poisson) summary(poisson)
Times to remission of leukemia patients
data(remission)data(remission)
A tibble with 42 observations and the following 3 variables.
timetime in weeks
groupgroup; C=control, T=treatment
censoredcensored; 0=No, 1=Yes
Gehan, E. A. (1965). A generalized Wilcoxon test for comparing arbitrarily singly-censored samples. Biometrika 52, 203–223.
data(remission) summary(remission)data(remission) summary(remission)
Data from a sample of elderly people given a psychiatric examination to determine whether symptoms of senility were present together with their score on a subset of the Wechsler Adult Intelligent Scale (WAIS).
data(senility)data(senility)
A tibble with 54 observations and the following 2 variables.
xWAIS score
ssymptoms of senility present; 1=yes, 0=no
data(senility) summary(senility)data(senility) summary(senility)
Average apparent per capita consumption of sugar (in kg per year) in Australia, as refined sugar and in manufactured foods
data(sugar)data(sugar)
A tibble with 6 observations and the following 3 variables.
periodperiod in years
refinedrefined sugar
manufacturedSugar in manufactured food
Australian Bureau of Statistics 1998
data(sugar) summary(sugar)data(sugar) summary(sugar)
Survival times for leukemia patients
data(survival)data(survival)
A tibble with 33 observations and the following 3 variables.
survival timesurvival time in weeks
WBCwhite blood cell count
AGtest result; +=positive, -=negative
Feigl, P. and M. Zelen (1965). Estimation of exponential probabilities with concomitant information. Biometrics 21, 826–838.
data(survival) summary(survival)data(survival) summary(survival)
Tumor responses of male and female patients receiving treatment for small-cell lung cancer
data(tumor)data(tumor)
A tibble with 16 observations and the following 4 variables.
treatmenttreatment; sequential or alternating
sexsex
responsefour category ordinal response
frequencyfrequency
Holtbrugger, W. and M. Schumacher (1991). A comparison of regression models for the analysis of ordered categorical data. Applied Statistics 40, 249–259.
data(tumor) summary(tumor)data(tumor) summary(tumor)
Data from a retrospective case-control study. A group of ulcer patients was compared with a group of control patients not known to have peptic ulcer, but who were similar to the ulcer patients with respect to age, sex and socioeconomic status.
data(ulcer)data(ulcer)
A tibble with 8 observations and the following 4 variables.
ulcertype of ulcer
case-controlcase or control
aspirinaspirin user
frequencyfrequency
Duggan, J. M., A. J. Dobson, H. Johnson, and P. P. Fahey (1986). Peptic ulcer and non-steroidal anti-inflammatory agents. Gut 27, 929–933.
data(ulcer) summary(ulcer)data(ulcer) summary(ulcer)
Unbalanced data from a fictitious two-factor experiment
data(unbalanced)data(unbalanced)
A tibble with 10 observations and the following 3 variables.
factorAfactor A
factorBfactor B
datadependent data
data(unbalanced) summary(unbalanced)data(unbalanced) summary(unbalanced)
Data from a vaccine trial.
data(vaccine)data(vaccine)
A tibble with 6 observations and the following 3 variables.
treatmenttreatment group
responseresponse to treatment
frequencyfrequency
R.S. Gillett
data(vaccine) summary(vaccine)data(vaccine) summary(vaccine)
The weights, in kilograms, of twenty men before and after participation in a "waist loss" program
data(waist)data(waist)
A tibble with 20 observations and the following 3 variables.
manman number
beforeweight before in kgs
afterweight after in kgs
Egger, G., G. Fisher, S. Piers, K. Bedford, G. Morseau, S. Sabasio, B. Taipim, G. Bani, M. Assan, and P. Mills (1999). Abdominal obesity reduction in Indigenous men. International Journal of Obesity 23, 564–569.
data(waist) summary(waist)data(waist) summary(waist)